==> novprog-3.0.0-1-src.tar.xz: novprog-3.0.0/translations/novprog_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <location filename="../src/graph.cpp" line="40"/>
        <source>%Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Επιλέξτε γλώσσα προγράμματος:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα συστήματος&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="170"/>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="170"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλώ επανεκκινήστε το πρόγραμμα για εφαρμογή της αλλαγής γλώσσας.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <location filename="../src/novel_dialog.cpp" line="47"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="51"/>
        <source>Goals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="56"/>
        <location filename="../src/novel_dialog.cpp" line="61"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="64"/>
        <source>Date Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="75"/>
        <source>Word Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="89"/>
        <source>Total:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="90"/>
        <source>Daily:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="93"/>
        <source>Start On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="94"/>
        <source>End On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="97"/>
        <source>Start At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="111"/>
        <source>Add Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="120"/>
        <source>Edit Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="137"/>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="137"/>
        <source>A novel already exists with that name.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="33"/>
        <source>Novel Progress</source>
        <translation>Πρόοδος έργου</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="68"/>
        <source>Total</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="73"/>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="81"/>
        <source>Word count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>&amp;Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="91"/>
        <source>&amp;New Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>&amp;Edit Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>&amp;Delete Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <location filename="../src/window.cpp" line="116"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="182"/>
        <source>Delete novel?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="184"/>
        <source>This action cannot be undone.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> novprog-3.1.2-1-src.tar.xz: novprog-3.1.2/translations/novprog_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln λέξεις</numerusform>
            <numerusform>%Ln λέξεις</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε γλώσσα προγράμματος:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλώ επανεκκινήστε το πρόγραμμα για εφαρμογή της αλλαγής γλώσσας.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Goals</source>
        <translation>Στόχοι</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Μη διαθέσιμο</translation>
    </message>
    <message>
        <source>Date Range</source>
        <translation>Χρονικό διάστημα</translation>
    </message>
    <message>
        <source>Word Count</source>
        <translation>Καταμέτρηση λέξεων</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Συνολικά:</translation>
    </message>
    <message>
        <source>Daily:</source>
        <translation>Ημερήσια:</translation>
    </message>
    <message>
        <source>Start On:</source>
        <translation>Έναρξη:</translation>
    </message>
    <message>
        <source>End On:</source>
        <translation>Λήξη:</translation>
    </message>
    <message>
        <source>Start At:</source>
        <translation>Έναρξη στις:</translation>
    </message>
    <message>
        <source>Add Novel</source>
        <translation>Προσθήκη έργου</translation>
    </message>
    <message>
        <source>Edit Novel</source>
        <translation>Επεξεργασία έργου</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Συγγνώμη</translation>
    </message>
    <message>
        <source>A novel already exists with that name.</source>
        <translation>Υπάρχει ήδη ένα έργο με αυτό το όνομα.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Novel Progress</source>
        <translation>Πρόοδος έργου</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Συνολικά</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Ημερήσια</translation>
    </message>
    <message>
        <source>Word count:</source>
        <translation>Καταμέτρηση λέξεων:</translation>
    </message>
    <message>
        <source>&amp;Novel</source>
        <translation>Έ&amp;ργο</translation>
    </message>
    <message>
        <source>&amp;New Novel</source>
        <translation>&amp;Νέο έργο</translation>
    </message>
    <message>
        <source>&amp;Edit Novel</source>
        <translation>&amp;Επεξεργασία έργου</translation>
    </message>
    <message>
        <source>&amp;Delete Novel</source>
        <translation>&amp;Διαγραφή έργου</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νέο</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Διαγρσφή</translation>
    </message>
    <message>
        <source>Delete novel?</source>
        <translation>Διαγραφή έργου;</translation>
    </message>
    <message>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation>Διαγραφή της προόδου για το έργο «%1»;</translation>
    </message>
    <message>
        <source>This action cannot be undone.</source>
        <translation>Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.</translation>
    </message>
</context>
</TS>
